"""Autogenerated API"""
from argus_api.session import _legacy_session as session
import logging
from argus_cli.plugin import register_command
from argus_plugins import argus_cli_module
log = logging.getLogger(__name__)


@register_command(
    extending=("eventfilters", "v2", "match"),
    module=argus_cli_module
)
def add_match_filter(
    name: str = None,
    description: str = None,
    customer: str = None,
    matchCode: str = None,
    minSeverity: str = None,
    maxSeverity: str = None,
    includeEventFlags: str = None,
    excludeEventFlags: str = None,
    protocol: str = None,
    domainPattern: str = None,
    uriPattern: str = None,
    sourceIPAddresses: str = None,
    sourcePorts: int = None,
    destinationIPAddresses: str = None,
    destinationPorts: int = None,
    sourceOrDestinationIPAddresses: str = None,
    sourceOrDestinationPorts: int = None,
    location: str = None,
    attackIdentifier: str = None,
    alarmID: int = None,
    attackCategory: str = None,
    sensorID: int = None,
    properties: dict = None,
    transformCode: str = None,
    newAggregationKey: str = None,
    newSeverity: str = None,
    associatedCaseID: int = None,
    newSourceAggregationBits: int = None,
    newDestinationAggregationBits: int = None,
    labels: str = None,
    validFrom: int = None,
    validTo: int = None,
    index: int = 5,
    drop: bool = None,
    noTransform: bool = None,
    continueAfterTransform: bool = None,
    stopAfterNoMatch: bool = None,
    changeAggregationKey: bool = None,
    invertIp: bool = None,
    enabled: bool = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Adds an match filter (DEV)
    
    :param str name: The name of the filter
    :param str description: A description of the filter
    :param str customer: The shortname or ID of the customer the filter belongs to. If customer is not set\, this will create a global filter
    :param str matchCode: Custom esper code for when the filter should match an event. Will be validated in the backend
    :param str minSeverity: Only match events with severity at least this value
    :param str maxSeverity: Only match events with severity this value or lower
    :param list includeEventFlags: Only match events that have these flags
    :param list excludeEventFlags: Only match events that does not have any of these flags
    :param str protocol: Only match events with the provided protocol
    :param str domainPattern: Only match events where the domain matches this regex
    :param str uriPattern: Only match events where the uri matches this regex
    :param list sourceIPAddresses: Only match events where the source ip address is in this set. This corresponds to intruder in the old solution
    :param list sourcePorts: Only match events where the source port is in this set. This corresponds to intruder in the old solution
    :param list destinationIPAddresses: Only match events where the destination ip address is in this set. This corresponds to victim in the old solution
    :param list destinationPorts: Only match events where the destination port is in this set. This corresponds to victim in the old solution
    :param list sourceOrDestinationIPAddresses: Only match events where an ip address is in this set. This corresponds to intruderOrVictim in the old solution
    :param list sourceOrDestinationPorts: Only match events where a port is in this set. This corresponds to intruderOrVictim in the old solution
    :param list location: Only match events from the these locations\, given by shortname or id
    :param list attackIdentifier: Only match events with these attack identifiers\, given by shortname or id
    :param list alarmID: Only match events connected to these alarms\, given by id
    :param list attackCategory: Only match events belonging to these attack categories\, given by shortname or id
    :param list sensorID: Only match events from these sensors\, given by id
    :param dict properties: Only match events which have these properties
    :param str transformCode: Custom esper code for how the event will be transformed. Will be validated in the backend
    :param str newAggregationKey: If set this will set a new aggregation key on the event\, given that changeAggregationKey is set to true
    :param str newSeverity: The new severity of events that are matched by the filter
    :param int associatedCaseID: Adds an associated case ID
    :param int newSourceAggregationBits: Changes the aggregation bits of the source ip to this value. Source corresponds to what was earlier called intruder
    :param int newDestinationAggregationBits: Changes the aggregation bits of the destination ip to this value. Destination corresponds to what was earlier called victim
    :param list labels: A set of labels which can be used to categorize the filter
    :param int validFrom: When the filter starts being applied. Timestamp can be milliseconds since epoch\, ISO8601 timestamp\, or a string with a relative timestamp. See the general integration guide for more details
    :param int validTo: When the filter stops being applied. Timestamp can be milliseconds since epoch\, ISO8601 timestamp\, or a string with a relative timestamp. See the general integration guide for more details
    :param int index: The index of the filter. Filters with lower index will be ran first. \(default 5\)
    :param bool drop: If true\, this event will be dropped \(default false\)
    :param bool noTransform: If true\, this event will not be transformed \(default false\)
    :param bool continueAfterTransform: If true\, this filter will continue to look for new events after transform \(default false\)
    :param bool stopAfterNoMatch: If true\, this filter will stop looking for new matches after not matching \(default false\)
    :param bool changeAggregationKey: If true\, this filter will change the aggregation key to the value of newAggregationKey \(default false\)
    :param bool invertIp: If true\, this filter will switch the source and destination ip in the event \(default false\)
    :param bool enabled: Whether or not the filter is enabled \(default false\)
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationFailedException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/eventfilters/v2/match".format()

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}
    # Only send name if the argument was provided, dont send null values
    if name is not None:
        body.update({"name": name})
    # Only send index if the argument was provided, dont send null values
    if index is not None:
        body.update({"index": index})
    # Only send description if the argument was provided, dont send null values
    if description is not None:
        body.update({"description": description})
    # Only send customer if the argument was provided, dont send null values
    if customer is not None:
        body.update({"customer": customer})
    # Only send matchCode if the argument was provided, dont send null values
    if matchCode is not None:
        body.update({"matchCode": matchCode})
    # Only send minSeverity if the argument was provided, dont send null values
    if minSeverity is not None:
        body.update({"minSeverity": minSeverity})
    # Only send maxSeverity if the argument was provided, dont send null values
    if maxSeverity is not None:
        body.update({"maxSeverity": maxSeverity})
    # Only send includeEventFlags if the argument was provided, dont send null values
    if includeEventFlags is not None:
        body.update({"includeEventFlags": includeEventFlags})
    # Only send excludeEventFlags if the argument was provided, dont send null values
    if excludeEventFlags is not None:
        body.update({"excludeEventFlags": excludeEventFlags})
    # Only send protocol if the argument was provided, dont send null values
    if protocol is not None:
        body.update({"protocol": protocol})
    # Only send domainPattern if the argument was provided, dont send null values
    if domainPattern is not None:
        body.update({"domainPattern": domainPattern})
    # Only send uriPattern if the argument was provided, dont send null values
    if uriPattern is not None:
        body.update({"uriPattern": uriPattern})
    # Only send sourceIPAddresses if the argument was provided, dont send null values
    if sourceIPAddresses is not None:
        body.update({"sourceIPAddresses": sourceIPAddresses})
    # Only send sourcePorts if the argument was provided, dont send null values
    if sourcePorts is not None:
        body.update({"sourcePorts": sourcePorts})
    # Only send destinationIPAddresses if the argument was provided, dont send null values
    if destinationIPAddresses is not None:
        body.update({"destinationIPAddresses": destinationIPAddresses})
    # Only send destinationPorts if the argument was provided, dont send null values
    if destinationPorts is not None:
        body.update({"destinationPorts": destinationPorts})
    # Only send sourceOrDestinationIPAddresses if the argument was provided, dont send null values
    if sourceOrDestinationIPAddresses is not None:
        body.update({"sourceOrDestinationIPAddresses": sourceOrDestinationIPAddresses})
    # Only send sourceOrDestinationPorts if the argument was provided, dont send null values
    if sourceOrDestinationPorts is not None:
        body.update({"sourceOrDestinationPorts": sourceOrDestinationPorts})
    # Only send location if the argument was provided, dont send null values
    if location is not None:
        body.update({"location": location})
    # Only send attackIdentifier if the argument was provided, dont send null values
    if attackIdentifier is not None:
        body.update({"attackIdentifier": attackIdentifier})
    # Only send alarmID if the argument was provided, dont send null values
    if alarmID is not None:
        body.update({"alarmID": alarmID})
    # Only send attackCategory if the argument was provided, dont send null values
    if attackCategory is not None:
        body.update({"attackCategory": attackCategory})
    # Only send sensorID if the argument was provided, dont send null values
    if sensorID is not None:
        body.update({"sensorID": sensorID})
    # Only send properties if the argument was provided, dont send null values
    if properties is not None:
        body.update({"properties": properties})
    # Only send transformCode if the argument was provided, dont send null values
    if transformCode is not None:
        body.update({"transformCode": transformCode})
    # Only send newAggregationKey if the argument was provided, dont send null values
    if newAggregationKey is not None:
        body.update({"newAggregationKey": newAggregationKey})
    # Only send newSeverity if the argument was provided, dont send null values
    if newSeverity is not None:
        body.update({"newSeverity": newSeverity})
    # Only send associatedCaseID if the argument was provided, dont send null values
    if associatedCaseID is not None:
        body.update({"associatedCaseID": associatedCaseID})
    # Only send newSourceAggregationBits if the argument was provided, dont send null values
    if newSourceAggregationBits is not None:
        body.update({"newSourceAggregationBits": newSourceAggregationBits})
    # Only send newDestinationAggregationBits if the argument was provided, dont send null values
    if newDestinationAggregationBits is not None:
        body.update({"newDestinationAggregationBits": newDestinationAggregationBits})
    # Only send drop if the argument was provided, dont send null values
    if drop is not None:
        body.update({"drop": drop})
    # Only send noTransform if the argument was provided, dont send null values
    if noTransform is not None:
        body.update({"noTransform": noTransform})
    # Only send continueAfterTransform if the argument was provided, dont send null values
    if continueAfterTransform is not None:
        body.update({"continueAfterTransform": continueAfterTransform})
    # Only send stopAfterNoMatch if the argument was provided, dont send null values
    if stopAfterNoMatch is not None:
        body.update({"stopAfterNoMatch": stopAfterNoMatch})
    # Only send changeAggregationKey if the argument was provided, dont send null values
    if changeAggregationKey is not None:
        body.update({"changeAggregationKey": changeAggregationKey})
    # Only send invertIp if the argument was provided, dont send null values
    if invertIp is not None:
        body.update({"invertIp": invertIp})
    # Only send labels if the argument was provided, dont send null values
    if labels is not None:
        body.update({"labels": labels})
    # Only send enabled if the argument was provided, dont send null values
    if enabled is not None:
        body.update({"enabled": enabled})
    # Only send validFrom if the argument was provided, dont send null values
    if validFrom is not None:
        body.update({"validFrom": validFrom})
    # Only send validTo if the argument was provided, dont send null values
    if validTo is not None:
        body.update({"validTo": validTo})

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("eventfilters", "v2", "match"),
    module=argus_cli_module
)
def debug_match_filter(
    id: int,
    eventIDs: str = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Shows the result of running a match filter against a set of events (DEV)
    
    :param int id: ID of filter
    :param list eventIDs: The list of event ids for the events to debug against. Can be given in the form of AGGR\/1\/123456789\/\{UUID\} or simply UUID.
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ObjectNotFoundException: on 404
    :raises ValidationFailedException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/eventfilters/v2/match/{id}/debug".format(id=id)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}
    # Only send eventIDs if the argument was provided, dont send null values
    if eventIDs is not None:
        body.update({"eventIDs": eventIDs})

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("eventfilters", "v2", "match"),
    module=argus_cli_module
)
def delete_match_filter(
    id: int,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Deletes a match filter (DEV)
    
    :param int id: ID of filter to delete
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ObjectNotFoundException: on 404
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/eventfilters/v2/match/{id}".format(id=id)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}

    query_parameters = {}
    log.debug("DELETE %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.delete(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("eventfilters", "v2", "match"),
    module=argus_cli_module
)
def duplicate_match_filter(
    id: int,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Duplicates a match filter (DEV)
    
    :param int id: ID of filter
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ObjectNotFoundException: on 404
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/eventfilters/v2/match/{id}/duplicate".format(id=id)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("eventfilters", "v2", "match"),
    module=argus_cli_module
)
def get_match_filter(
    id: int,
    includeCode: bool = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Gets an match filter (DEV)
    
    :param int id: ID of filter
    :param bool includeCode: Whether to include code in MatchFilter
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ObjectNotFoundException: on 404
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/eventfilters/v2/match/{id}".format(id=id,
        includeCode=includeCode)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}

    query_parameters = {}
    # Only send includeCode if the argument was provided, dont send null values
    if includeCode is not None:
        query_parameters.update({"includeCode": includeCode})
    
    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("eventfilters", "v2", "match"),
    module=argus_cli_module
)
def get_match_filter_status(
    id: int,
    limit: int = 25,
    offset: int = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Gets the status of a match filter (DEV)
    
    :param int id: ID of filter
    :param int limit: Limit result
    :param int offset: Offset result
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ObjectNotFoundException: on 404
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/eventfilters/v2/match/{id}/status".format(limit=limit,
        id=id,
        offset=offset)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}

    query_parameters = {}
    # Only send limit if the argument was provided, dont send null values
    if limit is not None:
        query_parameters.update({"limit": limit})
    
    # Only send offset if the argument was provided, dont send null values
    if offset is not None:
        query_parameters.update({"offset": offset})
    
    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("eventfilters", "v2", "match"),
    module=argus_cli_module
)
def list_match_filter(
    keywords: str = None,
    keywordField: str = None,
    timestampField: str = None,
    sortBy: str = None,
    keywordMatch: str = "all",
    timestampMatch: str = "all",
    limit: int = 25,
    start: int = None,
    end: int = None,
    includeCode: bool = None,
    offset: int = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Simple search for match filters (DEV)
    
    :param list keywords: Search by keywords
    :param list keywordField: Set field strategy for keyword search
    :param list timestampField: Set field strategy for timestamp filtering
    :param list sortBy: Field to sort by
    :param str keywordMatch: Set match strategy for keyword search
    :param str timestampMatch: Set match strategy for timestamp filtering
    :param int limit: Limit result
    :param int start: Lower bound timestamp filter value
    :param int end: Upper bound timestamp filter value
    :param bool includeCode: Whether to include code in results
    :param int offset: Offset result
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationFailedException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/eventfilters/v2/match".format(keywordMatch=keywordMatch,
        timestampMatch=timestampMatch,
        limit=limit,
        keywords=keywords,
        keywordField=keywordField,
        timestampField=timestampField,
        start=start,
        end=end,
        includeCode=includeCode,
        sortBy=sortBy,
        offset=offset)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}

    query_parameters = {}
    # Only send keywordMatch if the argument was provided, dont send null values
    if keywordMatch is not None:
        query_parameters.update({"keywordMatch": keywordMatch})
    
    # Only send timestampMatch if the argument was provided, dont send null values
    if timestampMatch is not None:
        query_parameters.update({"timestampMatch": timestampMatch})
    
    # Only send limit if the argument was provided, dont send null values
    if limit is not None:
        query_parameters.update({"limit": limit})
    
    # Only send keywords if the argument was provided, dont send null values
    if keywords is not None:
        query_parameters.update({"keywords": keywords})
    
    # Only send keywordField if the argument was provided, dont send null values
    if keywordField is not None:
        query_parameters.update({"keywordField": keywordField})
    
    # Only send timestampField if the argument was provided, dont send null values
    if timestampField is not None:
        query_parameters.update({"timestampField": timestampField})
    
    # Only send start if the argument was provided, dont send null values
    if start is not None:
        query_parameters.update({"start": start})
    
    # Only send end if the argument was provided, dont send null values
    if end is not None:
        query_parameters.update({"end": end})
    
    # Only send includeCode if the argument was provided, dont send null values
    if includeCode is not None:
        query_parameters.update({"includeCode": includeCode})
    
    # Only send sortBy if the argument was provided, dont send null values
    if sortBy is not None:
        query_parameters.update({"sortBy": sortBy})
    
    # Only send offset if the argument was provided, dont send null values
    if offset is not None:
        query_parameters.update({"offset": offset})
    
    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("eventfilters", "v2", "match"),
    module=argus_cli_module
)
def list_match_filter_revisions(
    id: int,
    limit: int = 25,
    offset: int = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Gets a match filters earlier revisions (DEV)
    
    :param int id: ID of filter to fetch revisions for
    :param int limit: The max amount of revisions to return
    :param int offset: The number of revisions to skip before returning
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ObjectNotFoundException: on 404
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/eventfilters/v2/match/{id}/revisions".format(limit=limit,
        id=id,
        offset=offset)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}

    query_parameters = {}
    # Only send limit if the argument was provided, dont send null values
    if limit is not None:
        query_parameters.update({"limit": limit})
    
    # Only send offset if the argument was provided, dont send null values
    if offset is not None:
        query_parameters.update({"offset": offset})
    
    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("eventfilters", "v2", "match"),
    module=argus_cli_module
)
def revive_match_filter(
    id: int,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Revives a deleted a match filter (DEV)
    
    :param int id: ID of filter
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ObjectNotFoundException: on 404
    :raises ValidationFailedException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/eventfilters/v2/match/{id}/revive".format(id=id)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}

    query_parameters = {}
    log.debug("PUT %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.put(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("eventfilters", "v2", "match"),
    module=argus_cli_module
)
def search_match_filter(
    order: str = None,
    sortBy: str = None,
    keywords: str = None,
    keywordFieldStrategy: str = None,
    keywordMatchStrategy: str = None,
    filterID: int = None,
    customer: str = None,
    user: str = None,
    userFieldStrategy: str = None,
    userMatchStrategy: str = None,
    timeFieldStrategy: str = None,
    timeMatchStrategy: str = None,
    includeFlags: str = None,
    excludeFlags: str = None,
    includeEventFlags: str = None,
    excludeEventFlags: str = None,
    location: str = None,
    alarmID: int = None,
    attackCategory: str = None,
    sensorID: int = None,
    subCriteria: dict = None,
    startTimestamp: int = None,
    endTimestamp: int = None,
    includeCode: bool = None,
    limit: int = 25,
    offset: int = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Searches for match filters (DEV)
    
    :param list order: 
    :param list sortBy: 
    :param list keywords: Search for keywords against fields defined by keywordFieldStrategy
    :param list keywordFieldStrategy: Defines which fields will be searched by keywords \(default all supported fields\) \(default all\)
    :param str keywordMatchStrategy: Defines how strict different keywords should be matched \(default match all keywords\) \(default all\)
    :param list filterID: Limit search to filters with the given IDs
    :param list customer: Limit search to filters with the given customers\, identified by id or shortname
    :param list user: Search using users identified by id or shortname. If given a group\, we will resolve all members of the group recursively
    :param list userFieldStrategy: Defines which fields will be searched by user \(default all supported fields\) \(default all\)
    :param str userMatchStrategy: Defines how strict different keywords should be matched \(default match all keywords\) \(default all\)
    :param list timeFieldStrategy: Defines which timestamps will be included in the search \(default lastUpdated\) \(default lastUpdated\)
    :param str timeMatchStrategy: Defines how strict to match against different timestamps \(all\/any\) using start and end timestamp \(default any\) \(default any\)
    :param list includeFlags: Limit to filters which have the following flags set
    :param list excludeFlags: Exclude filters which have the following flags set
    :param list includeEventFlags: Limit to filters which include the given event flags
    :param list excludeEventFlags: Limit to filters which exclude the given event flags
    :param list location: Limit to filters which target the following locations\, identified by id or shortname
    :param list alarmID: Limit to filters which target the following alarms
    :param list attackCategory: Limit to filters which target the following attack categories\, identified by id or shortname
    :param list sensorID: Limit to filters which target the following sensors
    :param list subCriteria: Subcriteria to add to the search
    :param int startTimestamp: Restrict to a time frame based on the set timeFieldStrategy \(start timestamp\) \(default 0\)
    :param int endTimestamp: Restrict to a time frame based on the set timeFieldStrategy \(end timestamp\) \(default 0\)
    :param bool includeCode: Whether or not to include code in the result object. The code is only returned if set to true \(default false\)
    :param int limit: Limit maximum amount of results \(default 25\)
    :param int offset: Skip specified amount of results \(default 0\)
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationFailedException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/eventfilters/v2/match/search".format()

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}
    # Only send order if the argument was provided, dont send null values
    if order is not None:
        body.update({"order": order})
    # Only send sortBy if the argument was provided, dont send null values
    if sortBy is not None:
        body.update({"sortBy": sortBy})
    # Only send keywords if the argument was provided, dont send null values
    if keywords is not None:
        body.update({"keywords": keywords})
    # Only send keywordFieldStrategy if the argument was provided, dont send null values
    if keywordFieldStrategy is not None:
        body.update({"keywordFieldStrategy": keywordFieldStrategy})
    # Only send keywordMatchStrategy if the argument was provided, dont send null values
    if keywordMatchStrategy is not None:
        body.update({"keywordMatchStrategy": keywordMatchStrategy})
    # Only send filterID if the argument was provided, dont send null values
    if filterID is not None:
        body.update({"filterID": filterID})
    # Only send customer if the argument was provided, dont send null values
    if customer is not None:
        body.update({"customer": customer})
    # Only send user if the argument was provided, dont send null values
    if user is not None:
        body.update({"user": user})
    # Only send userFieldStrategy if the argument was provided, dont send null values
    if userFieldStrategy is not None:
        body.update({"userFieldStrategy": userFieldStrategy})
    # Only send userMatchStrategy if the argument was provided, dont send null values
    if userMatchStrategy is not None:
        body.update({"userMatchStrategy": userMatchStrategy})
    # Only send startTimestamp if the argument was provided, dont send null values
    if startTimestamp is not None:
        body.update({"startTimestamp": startTimestamp})
    # Only send endTimestamp if the argument was provided, dont send null values
    if endTimestamp is not None:
        body.update({"endTimestamp": endTimestamp})
    # Only send timeFieldStrategy if the argument was provided, dont send null values
    if timeFieldStrategy is not None:
        body.update({"timeFieldStrategy": timeFieldStrategy})
    # Only send timeMatchStrategy if the argument was provided, dont send null values
    if timeMatchStrategy is not None:
        body.update({"timeMatchStrategy": timeMatchStrategy})
    # Only send includeFlags if the argument was provided, dont send null values
    if includeFlags is not None:
        body.update({"includeFlags": includeFlags})
    # Only send excludeFlags if the argument was provided, dont send null values
    if excludeFlags is not None:
        body.update({"excludeFlags": excludeFlags})
    # Only send includeEventFlags if the argument was provided, dont send null values
    if includeEventFlags is not None:
        body.update({"includeEventFlags": includeEventFlags})
    # Only send excludeEventFlags if the argument was provided, dont send null values
    if excludeEventFlags is not None:
        body.update({"excludeEventFlags": excludeEventFlags})
    # Only send location if the argument was provided, dont send null values
    if location is not None:
        body.update({"location": location})
    # Only send alarmID if the argument was provided, dont send null values
    if alarmID is not None:
        body.update({"alarmID": alarmID})
    # Only send attackCategory if the argument was provided, dont send null values
    if attackCategory is not None:
        body.update({"attackCategory": attackCategory})
    # Only send sensorID if the argument was provided, dont send null values
    if sensorID is not None:
        body.update({"sensorID": sensorID})
    # Only send subCriteria if the argument was provided, dont send null values
    if subCriteria is not None:
        body.update({"subCriteria": subCriteria})
    # Only send includeCode if the argument was provided, dont send null values
    if includeCode is not None:
        body.update({"includeCode": includeCode})
    # Only send limit if the argument was provided, dont send null values
    if limit is not None:
        body.update({"limit": limit})
    # Only send offset if the argument was provided, dont send null values
    if offset is not None:
        body.update({"offset": offset})

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("eventfilters", "v2", "match"),
    module=argus_cli_module
)
def set_match_filter_log_level(
    id: int,
    logLevel: str = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Sets the log level of a match filter (DEV)
    
    :param int id: ID of filter
    :param str logLevel: The new log level of the filter
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ObjectNotFoundException: on 404
    :raises ValidationFailedException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/eventfilters/v2/match/{id}/logging".format(id=id)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}
    # Only send logLevel if the argument was provided, dont send null values
    if logLevel is not None:
        body.update({"logLevel": logLevel})

    query_parameters = {}
    log.debug("PUT %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.put(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("eventfilters", "v2", "match"),
    module=argus_cli_module
)
def update_match_filter(
    id: int,
    enabled: bool = None,
    name: str = None,
    index: int = None,
    validFrom: int = None,
    validTo: int = None,
    description: str = None,
    matchCode: str = None,
    minSeverity: str = None,
    maxSeverity: str = None,
    includeEventFlags: str = None,
    excludeEventFlags: str = None,
    protocol: str = None,
    domainPattern: str = None,
    uriPattern: str = None,
    sourceIPAddresses: str = None,
    sourcePorts: int = None,
    destinationIPAddresses: str = None,
    destinationPorts: int = None,
    sourceOrDestinationIPAddresses: str = None,
    sourceOrDestinationPorts: int = None,
    location: str = None,
    attackIdentifier: str = None,
    alarmID: int = None,
    attackCategory: str = None,
    sensorID: int = None,
    properties: dict = None,
    transformCode: str = None,
    newAggregationKey: str = None,
    newSeverity: str = None,
    associatedCaseID: int = None,
    newSourceAggregationBits: int = None,
    newDestinationAggregationBits: int = None,
    drop: bool = None,
    noTransform: bool = None,
    continueAfterTransform: bool = None,
    stopAfterNoMatch: bool = None,
    changeAggregationKey: bool = None,
    invertIp: bool = None,
    removeLabels: str = None,
    addLabels: str = None,
    setLabels: str = None,
    comment: str = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Updates a match filter (DEV)
    
    :param int id: ID of filter
    :param bool enabled: 
    :param str name: The name of the filter
    :param int index: The index of the filter. Filters with lower index will be ran first.
    :param int validFrom: When the filter starts being applied. Timestamp can be milliseconds since epoch\, ISO8601 timestamp\, or a string with a relative timestamp. See the general integration guide for more details
    :param int validTo: When the filter stops being applied. Timestamp can be milliseconds since epoch\, ISO8601 timestamp\, or a string with a relative timestamp. See the general integration guide for more details
    :param str description: A description of the filter
    :param str matchCode: Custom esper code for when the filter should match an event. Will be validated in the backend
    :param str minSeverity: Only match events with severity at least this value
    :param str maxSeverity: Only match events with severity this value or lower
    :param list includeEventFlags: Only match events that have these flags
    :param list excludeEventFlags: Only match events that does not have any of these flags
    :param str protocol: Only match events with the provided protocol
    :param str domainPattern: Only match events where the domain matches this regex
    :param str uriPattern: Only match events where the uri matches this regex
    :param list sourceIPAddresses: Only match events where the source ip address is in this set. This corresponds to intruder in the old solution
    :param list sourcePorts: Only match events where the source port is in this set. This corresponds to intruder in the old solution
    :param list destinationIPAddresses: Only match events where the destination ip address is in this set. This corresponds to victim in the old solution
    :param list destinationPorts: Only match events where the destination port is in this set. This corresponds to victim in the old solution
    :param list sourceOrDestinationIPAddresses: Only match events where an ip address is in this set. This corresponds to intruderOrVictim in the old solution
    :param list sourceOrDestinationPorts: Only match events where a port is in this set. This corresponds to intruderOrVictim in the old solution
    :param list location: Only match events from the these locations\, given by shortname or id
    :param list attackIdentifier: Only match events with these attack identifiers\, given by shortname or id
    :param list alarmID: Only match events connected to these alarms\, given by id
    :param list attackCategory: Only match events belonging to these attack categories\, given by shortname or id
    :param list sensorID: Only match events from these sensors\, given by id
    :param dict properties: Only match events which have these properties
    :param str transformCode: Custom esper code for how the event will be transformed. Will be validated in the backend
    :param str newAggregationKey: If set this will set a new aggregation key on the event\, given that changeAggregationKey is set to true
    :param str newSeverity: The new severity of events that are matched by the filter
    :param int associatedCaseID: Adds an associated case ID
    :param int newSourceAggregationBits: Changes the aggregation bits of the source ip to this value. Source corresponds to what was earlier called intruder
    :param int newDestinationAggregationBits: Changes the aggregation bits of the destination ip to this value. Destination corresponds to what was earlier called victim
    :param bool drop: If true\, this event will be dropped
    :param bool noTransform: If true\, this event will not be transformed
    :param bool continueAfterTransform: If true\, this filter will continue to look for new events after transform
    :param bool stopAfterNoMatch: If true\, this filter will stop looking for new matches after not matching
    :param bool changeAggregationKey: If true\, this filter will change the aggregation key to the value of newAggregationKey
    :param bool invertIp: If true\, this filter will switch the source and destination ip in the event
    :param list removeLabels: A set of labels to remove from the filter.  Will be applied before adding labels and ignore filters that are not present. Will throw an exception if used in conjunction with setLabels 
    :param list addLabels: A set of labels to add to the filter.  Will be applied after removing labels. Will throw an exception if used in conjunction with setLabels 
    :param list setLabels: Replace the current set of labels with these. Will throw an exception if used in conjunction with addLabels or removeLabels
    :param str comment: A comment describing why the filter was created
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ObjectNotFoundException: on 404
    :raises ValidationFailedException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/eventfilters/v2/match/{id}".format(id=id)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}
    # Only send enabled if the argument was provided, dont send null values
    if enabled is not None:
        body.update({"enabled": enabled})
    # Only send name if the argument was provided, dont send null values
    if name is not None:
        body.update({"name": name})
    # Only send index if the argument was provided, dont send null values
    if index is not None:
        body.update({"index": index})
    # Only send validFrom if the argument was provided, dont send null values
    if validFrom is not None:
        body.update({"validFrom": validFrom})
    # Only send validTo if the argument was provided, dont send null values
    if validTo is not None:
        body.update({"validTo": validTo})
    # Only send description if the argument was provided, dont send null values
    if description is not None:
        body.update({"description": description})
    # Only send matchCode if the argument was provided, dont send null values
    if matchCode is not None:
        body.update({"matchCode": matchCode})
    # Only send minSeverity if the argument was provided, dont send null values
    if minSeverity is not None:
        body.update({"minSeverity": minSeverity})
    # Only send maxSeverity if the argument was provided, dont send null values
    if maxSeverity is not None:
        body.update({"maxSeverity": maxSeverity})
    # Only send includeEventFlags if the argument was provided, dont send null values
    if includeEventFlags is not None:
        body.update({"includeEventFlags": includeEventFlags})
    # Only send excludeEventFlags if the argument was provided, dont send null values
    if excludeEventFlags is not None:
        body.update({"excludeEventFlags": excludeEventFlags})
    # Only send protocol if the argument was provided, dont send null values
    if protocol is not None:
        body.update({"protocol": protocol})
    # Only send domainPattern if the argument was provided, dont send null values
    if domainPattern is not None:
        body.update({"domainPattern": domainPattern})
    # Only send uriPattern if the argument was provided, dont send null values
    if uriPattern is not None:
        body.update({"uriPattern": uriPattern})
    # Only send sourceIPAddresses if the argument was provided, dont send null values
    if sourceIPAddresses is not None:
        body.update({"sourceIPAddresses": sourceIPAddresses})
    # Only send sourcePorts if the argument was provided, dont send null values
    if sourcePorts is not None:
        body.update({"sourcePorts": sourcePorts})
    # Only send destinationIPAddresses if the argument was provided, dont send null values
    if destinationIPAddresses is not None:
        body.update({"destinationIPAddresses": destinationIPAddresses})
    # Only send destinationPorts if the argument was provided, dont send null values
    if destinationPorts is not None:
        body.update({"destinationPorts": destinationPorts})
    # Only send sourceOrDestinationIPAddresses if the argument was provided, dont send null values
    if sourceOrDestinationIPAddresses is not None:
        body.update({"sourceOrDestinationIPAddresses": sourceOrDestinationIPAddresses})
    # Only send sourceOrDestinationPorts if the argument was provided, dont send null values
    if sourceOrDestinationPorts is not None:
        body.update({"sourceOrDestinationPorts": sourceOrDestinationPorts})
    # Only send location if the argument was provided, dont send null values
    if location is not None:
        body.update({"location": location})
    # Only send attackIdentifier if the argument was provided, dont send null values
    if attackIdentifier is not None:
        body.update({"attackIdentifier": attackIdentifier})
    # Only send alarmID if the argument was provided, dont send null values
    if alarmID is not None:
        body.update({"alarmID": alarmID})
    # Only send attackCategory if the argument was provided, dont send null values
    if attackCategory is not None:
        body.update({"attackCategory": attackCategory})
    # Only send sensorID if the argument was provided, dont send null values
    if sensorID is not None:
        body.update({"sensorID": sensorID})
    # Only send properties if the argument was provided, dont send null values
    if properties is not None:
        body.update({"properties": properties})
    # Only send transformCode if the argument was provided, dont send null values
    if transformCode is not None:
        body.update({"transformCode": transformCode})
    # Only send newAggregationKey if the argument was provided, dont send null values
    if newAggregationKey is not None:
        body.update({"newAggregationKey": newAggregationKey})
    # Only send newSeverity if the argument was provided, dont send null values
    if newSeverity is not None:
        body.update({"newSeverity": newSeverity})
    # Only send associatedCaseID if the argument was provided, dont send null values
    if associatedCaseID is not None:
        body.update({"associatedCaseID": associatedCaseID})
    # Only send newSourceAggregationBits if the argument was provided, dont send null values
    if newSourceAggregationBits is not None:
        body.update({"newSourceAggregationBits": newSourceAggregationBits})
    # Only send newDestinationAggregationBits if the argument was provided, dont send null values
    if newDestinationAggregationBits is not None:
        body.update({"newDestinationAggregationBits": newDestinationAggregationBits})
    # Only send drop if the argument was provided, dont send null values
    if drop is not None:
        body.update({"drop": drop})
    # Only send noTransform if the argument was provided, dont send null values
    if noTransform is not None:
        body.update({"noTransform": noTransform})
    # Only send continueAfterTransform if the argument was provided, dont send null values
    if continueAfterTransform is not None:
        body.update({"continueAfterTransform": continueAfterTransform})
    # Only send stopAfterNoMatch if the argument was provided, dont send null values
    if stopAfterNoMatch is not None:
        body.update({"stopAfterNoMatch": stopAfterNoMatch})
    # Only send changeAggregationKey if the argument was provided, dont send null values
    if changeAggregationKey is not None:
        body.update({"changeAggregationKey": changeAggregationKey})
    # Only send invertIp if the argument was provided, dont send null values
    if invertIp is not None:
        body.update({"invertIp": invertIp})
    # Only send removeLabels if the argument was provided, dont send null values
    if removeLabels is not None:
        body.update({"removeLabels": removeLabels})
    # Only send addLabels if the argument was provided, dont send null values
    if addLabels is not None:
        body.update({"addLabels": addLabels})
    # Only send setLabels if the argument was provided, dont send null values
    if setLabels is not None:
        body.update({"setLabels": setLabels})
    # Only send comment if the argument was provided, dont send null values
    if comment is not None:
        body.update({"comment": comment})

    query_parameters = {}
    log.debug("PUT %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.put(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response
