"""Autogenerated API"""
from argus_api.session import _legacy_session as session
import logging
from argus_cli.plugin import register_command
from argus_plugins import argus_cli_module
from argus_api.utils import deprecated_alias
log = logging.getLogger(__name__)


@register_command(
    extending=("reputation", "v1", "observation"),
    module=argus_cli_module
)
def add_observations(
    sourceID: int = None,
    sourceAlias: str = None,
    observations: dict = None,
    addAddresses: bool = True,
    addDomains: bool = True,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Add reputation observations (INTERNAL)
    
    :param int sourceID: 
    :param str sourceAlias: 
    :param list observations: Observations
    :param bool addAddresses: Whether add addresses \(default true\)
    :param bool addDomains: Whether add domains \(default true\)
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/reputation/v1/observation".format()

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}
    # Only send sourceID if the argument was provided, dont send null values
    if sourceID is not None:
        body.update({"sourceID": sourceID})
    # Only send sourceAlias if the argument was provided, dont send null values
    if sourceAlias is not None:
        body.update({"sourceAlias": sourceAlias})
    # Only send addAddresses if the argument was provided, dont send null values
    if addAddresses is not None:
        body.update({"addAddresses": addAddresses})
    # Only send addDomains if the argument was provided, dont send null values
    if addDomains is not None:
        body.update({"addDomains": addDomains})
    # Only send observations if the argument was provided, dont send null values
    if observations is not None:
        body.update({"observations": observations})

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("reputation", "v1", "observation"),
    module=argus_cli_module
)
def delete_observations(
    sourceAlias: str = None,
    address: str = None,
    fqdn: str = None,
    sourceID: int = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Delete reputation observations (INTERNAL)
    
    :param str sourceAlias: Source alias
    :param list address: IP Addresses
    :param list fqdn: Domain names
    :param int sourceID: Source ID
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/reputation/v1/observation".format(sourceID=sourceID,
        sourceAlias=sourceAlias,
        address=address,
        fqdn=fqdn)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}

    query_parameters = {}
    # Only send sourceID if the argument was provided, dont send null values
    if sourceID is not None:
        query_parameters.update({"sourceID": sourceID})
    
    # Only send sourceAlias if the argument was provided, dont send null values
    if sourceAlias is not None:
        query_parameters.update({"sourceAlias": sourceAlias})
    
    # Only send address if the argument was provided, dont send null values
    if address is not None:
        query_parameters.update({"address": address})
    
    # Only send fqdn if the argument was provided, dont send null values
    if fqdn is not None:
        query_parameters.update({"fqdn": fqdn})
    
    log.debug("DELETE %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.delete(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("reputation", "v1", "observation"),
    module=argus_cli_module
)
def fetch_observations_for_domain(
    fqdn: str,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Look up reputation observations for the given domain (INTERNAL)
    
    :param str fqdn: Domain to fetch observations for
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/reputation/v1/observation/domain/{fqdn}".format(fqdn=fqdn)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}

    query_parameters = {}
    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("reputation", "v1", "observation"),
    module=argus_cli_module
)
def fetch_observations_for_ip(
    ip: str,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Look up reputation observations for the given IP (INTERNAL)
    
    :param str ip: IP address to fetch observations for
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/reputation/v1/observation/ip/{ip}".format(ip=ip)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}

    query_parameters = {}
    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("reputation", "v1", "observation"),
    module=argus_cli_module
)
def find_address_observations(
    minimumState: int = None,
    minimumConfidence: float = None,
    sourceID: int = None,
    fromAddress: dict = None,
    afterAddress: dict = None,
    limit: int = None,
    offset: int = None,
    includeDeleted: bool = None,
    includeFlags: int = None,
    excludeFlags: int = None,
    subCriteria: dict = None,
    exclude: bool = None,
    required: bool = None,
    startTimestamp: str = None,
    endTimestamp: str = None,
    addresses: dict = None,
    sortBy: str = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """List IP observations (INTERNAL)
    
    :param int minimumState: 
    :param float minimumConfidence: 
    :param list sourceID: 
    :param dict fromAddress: 
    :param dict afterAddress: 
    :param int limit: Max number of results.
    :param int offset: Skip the first \(offset\) objects. By default\, return result from first object.
    :param bool includeDeleted: Set to true to include deleted objects. By default\, exclude deleted objects.
    :param int includeFlags: Only include objects which have includeFlags set.
    :param int excludeFlags: Exclude objects which have excludeFlags set.
    :param list subCriteria: Set additional criterias which are applied using a logical OR.
    :param bool exclude: Only relevant for subcriteria. If set to true\, objects matching this subcriteria object will be excluded.
    :param bool required: Only relevant for subcriteria. If set to true\, objects matching this subcriteria are required \(AND\-ed together with parent criteria\).
    :param str startTimestamp: Restrict search to data after this time \(epoch millis\) according to selected TimeFieldStrategies. Allows unix timestamp \(milliseconds\)\, ISO timestamp\, or relative time specifies. See https\:\/\/docs.mnemonic.no\/x\/AQDXAQ
    :param str endTimestamp: Restrict search to data before this time \(epoch millis\) according to selected TimeFieldStrategies. Allows unix timestamp \(milliseconds\)\, ISO timestamp\, or relative time specifies. See https\:\/\/docs.mnemonic.no\/x\/AQDXAQ
    :param list addresses: Set of IP addresses
    :param list sortBy: List of properties to sort by \(prefix with \"\-\" to sort descending\).
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/reputation/v1/observation/ip/search".format()

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}
    # Only send minimumState if the argument was provided, dont send null values
    if minimumState is not None:
        body.update({"minimumState": minimumState})
    # Only send minimumConfidence if the argument was provided, dont send null values
    if minimumConfidence is not None:
        body.update({"minimumConfidence": minimumConfidence})
    # Only send sourceID if the argument was provided, dont send null values
    if sourceID is not None:
        body.update({"sourceID": sourceID})
    # Only send fromAddress if the argument was provided, dont send null values
    if fromAddress is not None:
        body.update({"fromAddress": fromAddress})
    # Only send afterAddress if the argument was provided, dont send null values
    if afterAddress is not None:
        body.update({"afterAddress": afterAddress})
    # Only send limit if the argument was provided, dont send null values
    if limit is not None:
        body.update({"limit": limit})
    # Only send offset if the argument was provided, dont send null values
    if offset is not None:
        body.update({"offset": offset})
    # Only send includeDeleted if the argument was provided, dont send null values
    if includeDeleted is not None:
        body.update({"includeDeleted": includeDeleted})
    # Only send includeFlags if the argument was provided, dont send null values
    if includeFlags is not None:
        body.update({"includeFlags": includeFlags})
    # Only send excludeFlags if the argument was provided, dont send null values
    if excludeFlags is not None:
        body.update({"excludeFlags": excludeFlags})
    # Only send subCriteria if the argument was provided, dont send null values
    if subCriteria is not None:
        body.update({"subCriteria": subCriteria})
    # Only send exclude if the argument was provided, dont send null values
    if exclude is not None:
        body.update({"exclude": exclude})
    # Only send required if the argument was provided, dont send null values
    if required is not None:
        body.update({"required": required})
    # Only send startTimestamp if the argument was provided, dont send null values
    if startTimestamp is not None:
        body.update({"startTimestamp": startTimestamp})
    # Only send endTimestamp if the argument was provided, dont send null values
    if endTimestamp is not None:
        body.update({"endTimestamp": endTimestamp})
    # Only send addresses if the argument was provided, dont send null values
    if addresses is not None:
        body.update({"addresses": addresses})
    # Only send sortBy if the argument was provided, dont send null values
    if sortBy is not None:
        body.update({"sortBy": sortBy})

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("reputation", "v1", "observation"),
    module=argus_cli_module
)
def find_domain_observations(
    minimumState: int = None,
    minimumConfidence: float = None,
    sourceID: int = None,
    fromDomainName: dict = None,
    afterDomainName: dict = None,
    limit: int = None,
    offset: int = None,
    includeDeleted: bool = None,
    includeFlags: int = None,
    excludeFlags: int = None,
    subCriteria: dict = None,
    exclude: bool = None,
    required: bool = None,
    startTimestamp: str = None,
    endTimestamp: str = None,
    domainNames: dict = None,
    sortBy: str = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """List domain observations (INTERNAL)
    
    :param int minimumState: 
    :param float minimumConfidence: 
    :param list sourceID: 
    :param dict fromDomainName: 
    :param dict afterDomainName: 
    :param int limit: Max number of results.
    :param int offset: Skip the first \(offset\) objects. By default\, return result from first object.
    :param bool includeDeleted: Set to true to include deleted objects. By default\, exclude deleted objects.
    :param int includeFlags: Only include objects which have includeFlags set.
    :param int excludeFlags: Exclude objects which have excludeFlags set.
    :param list subCriteria: Set additional criterias which are applied using a logical OR.
    :param bool exclude: Only relevant for subcriteria. If set to true\, objects matching this subcriteria object will be excluded.
    :param bool required: Only relevant for subcriteria. If set to true\, objects matching this subcriteria are required \(AND\-ed together with parent criteria\).
    :param str startTimestamp: Restrict search to data after this time \(epoch millis\) according to selected TimeFieldStrategies. Allows unix timestamp \(milliseconds\)\, ISO timestamp\, or relative time specifies. See https\:\/\/docs.mnemonic.no\/x\/AQDXAQ
    :param str endTimestamp: Restrict search to data before this time \(epoch millis\) according to selected TimeFieldStrategies. Allows unix timestamp \(milliseconds\)\, ISO timestamp\, or relative time specifies. See https\:\/\/docs.mnemonic.no\/x\/AQDXAQ
    :param list domainNames: List of Full Qualified Domain Names
    :param list sortBy: List of properties to sort by \(prefix with \"\-\" to sort descending\).
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/reputation/v1/observation/domain/search".format()

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}
    # Only send minimumState if the argument was provided, dont send null values
    if minimumState is not None:
        body.update({"minimumState": minimumState})
    # Only send minimumConfidence if the argument was provided, dont send null values
    if minimumConfidence is not None:
        body.update({"minimumConfidence": minimumConfidence})
    # Only send sourceID if the argument was provided, dont send null values
    if sourceID is not None:
        body.update({"sourceID": sourceID})
    # Only send fromDomainName if the argument was provided, dont send null values
    if fromDomainName is not None:
        body.update({"fromDomainName": fromDomainName})
    # Only send afterDomainName if the argument was provided, dont send null values
    if afterDomainName is not None:
        body.update({"afterDomainName": afterDomainName})
    # Only send limit if the argument was provided, dont send null values
    if limit is not None:
        body.update({"limit": limit})
    # Only send offset if the argument was provided, dont send null values
    if offset is not None:
        body.update({"offset": offset})
    # Only send includeDeleted if the argument was provided, dont send null values
    if includeDeleted is not None:
        body.update({"includeDeleted": includeDeleted})
    # Only send includeFlags if the argument was provided, dont send null values
    if includeFlags is not None:
        body.update({"includeFlags": includeFlags})
    # Only send excludeFlags if the argument was provided, dont send null values
    if excludeFlags is not None:
        body.update({"excludeFlags": excludeFlags})
    # Only send subCriteria if the argument was provided, dont send null values
    if subCriteria is not None:
        body.update({"subCriteria": subCriteria})
    # Only send exclude if the argument was provided, dont send null values
    if exclude is not None:
        body.update({"exclude": exclude})
    # Only send required if the argument was provided, dont send null values
    if required is not None:
        body.update({"required": required})
    # Only send startTimestamp if the argument was provided, dont send null values
    if startTimestamp is not None:
        body.update({"startTimestamp": startTimestamp})
    # Only send endTimestamp if the argument was provided, dont send null values
    if endTimestamp is not None:
        body.update({"endTimestamp": endTimestamp})
    # Only send domainNames if the argument was provided, dont send null values
    if domainNames is not None:
        body.update({"domainNames": domainNames})
    # Only send sortBy if the argument was provided, dont send null values
    if sortBy is not None:
        body.update({"sortBy": sortBy})

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("reputation", "v1", "observation"),
    module=argus_cli_module
)
def list_address_observations(
    sourceID: int = None,
    minimumState: int = None,
    minimumConfidence: float = None,
    limit: int = 25,
    offset: int = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """List IP observations (INTERNAL)
    
    :param int sourceID: Limit result to observations from specified source
    :param int minimumState: Limit result to observations with this state or higher
    :param float minimumConfidence: Limit result to observations bound to sources with at least this confidence
    :param int limit: Limit result
    :param int offset: Offset result
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/reputation/v1/observation/ip".format(limit=limit,
        sourceID=sourceID,
        minimumState=minimumState,
        minimumConfidence=minimumConfidence,
        offset=offset)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}

    query_parameters = {}
    # Only send limit if the argument was provided, dont send null values
    if limit is not None:
        query_parameters.update({"limit": limit})
    
    # Only send sourceID if the argument was provided, dont send null values
    if sourceID is not None:
        query_parameters.update({"sourceID": sourceID})
    
    # Only send minimumState if the argument was provided, dont send null values
    if minimumState is not None:
        query_parameters.update({"minimumState": minimumState})
    
    # Only send minimumConfidence if the argument was provided, dont send null values
    if minimumConfidence is not None:
        query_parameters.update({"minimumConfidence": minimumConfidence})
    
    # Only send offset if the argument was provided, dont send null values
    if offset is not None:
        query_parameters.update({"offset": offset})
    
    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("reputation", "v1", "observation"),
    module=argus_cli_module
)
def list_domain_observations(
    sourceID: int = None,
    minimumState: int = None,
    minimumConfidence: float = None,
    limit: int = 25,
    offset: int = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """List domain observations (INTERNAL)
    
    :param int sourceID: Limit result to observations from specified source
    :param int minimumState: Limit result to observations with this state or higher
    :param float minimumConfidence: Limit result to observations bound to sources with at least this confidence
    :param int limit: Limit result
    :param int offset: Offset result
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/reputation/v1/observation/domain".format(limit=limit,
        sourceID=sourceID,
        minimumState=minimumState,
        minimumConfidence=minimumConfidence,
        offset=offset)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}

    query_parameters = {}
    # Only send limit if the argument was provided, dont send null values
    if limit is not None:
        query_parameters.update({"limit": limit})
    
    # Only send sourceID if the argument was provided, dont send null values
    if sourceID is not None:
        query_parameters.update({"sourceID": sourceID})
    
    # Only send minimumState if the argument was provided, dont send null values
    if minimumState is not None:
        query_parameters.update({"minimumState": minimumState})
    
    # Only send minimumConfidence if the argument was provided, dont send null values
    if minimumConfidence is not None:
        query_parameters.update({"minimumConfidence": minimumConfidence})
    
    # Only send offset if the argument was provided, dont send null values
    if offset is not None:
        query_parameters.update({"offset": offset})
    
    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

#: **DEPRECATED** : ``fetch_observations_for_i_p`` is an alias for ``fetch_observations_for_ip``. Exists
#: only for backward compatibility - **do not use** - use ``fetch_observations_for_ip`` instead.
fetch_observations_for_i_p = register_command(
    extending=("reputation", "v1", "observation"),
    module=argus_cli_module,
    alias="fetch_observations_for_i_p"
)(deprecated_alias("fetch_observations_for_i_p")(fetch_observations_for_ip))