"""Autogenerated API"""
from argus_api.session import get_session
from typing import TYPE_CHECKING, Optional
if TYPE_CHECKING:
    from argus_api.session import ArgusAPISession
from argus_api.utils import deprecated_alias


def submit_client_log_events_bulk(
    logEntries: dict = None,
    ignoreOnFailed: bool = None,
    json: bool = True,
    verify: Optional[bool] = None,
    proxies: Optional[dict] = None,
    apiKey: Optional[str] = None,
    authentication: Optional[dict] = None,
    server_url: Optional[str] = None,
    body: Optional[dict] = None,
    api_session: Optional["ArgusAPISession"] = None,
) -> dict:
    """Submit client log events in a bulk operation (INTERNAL)
    
    :param list logEntries: Log entries for submission.
    :param bool ignoreOnFailed: Set this value for successful response even with failures occur while submitting. \(default false\)
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :param api_session: session to use for this request. If not set, the global session will be used.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationFailedException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/logging/v1/client".format()

    session = api_session or get_session()

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = body or {}
    # Only send logEntries if the argument was provided, dont send null values
    if logEntries is not None:
        body.update({"logEntries": logEntries})
    # Only send ignoreOnFailed if the argument was provided, dont send null values
    if ignoreOnFailed is not None:
        body.update({"ignoreOnFailed": ignoreOnFailed})

    query_parameters = {}

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

#: **DEPRECATED** : ``submit_log_events_bulk`` is an alias for ``submit_client_log_events_bulk``. Exists
#: only for backward compatibility - **do not use** - use ``submit_client_log_events_bulk`` instead.
submit_log_events_bulk = deprecated_alias("submit_log_events_bulk")(submit_client_log_events_bulk)